#ifndef RANDOMH
#define RANDOMH

/** 
   \file random.h

   \brief Definition of  basic randomization functions. 

   Definition of basic randomization functions. 
   
   \sa random.c.
*/


/** 
   \brief Resets the random seed.

   Resets the random seed using the current time so, in principle,
   the reset is hard to predict.
*/
void randomReset();

/** 
   \brief Sets the random seed.

   Sets the random to the given value. This is used to get
   repetitive sequences of \e random numbers in order to debug
   mainly.

   \param seed The new random seed.
*/
void randomSet(unsigned int seed);

/** 
   \brief Returns a random double in the [0,1] interval.

   Returns a random number in the [0,1] interval selected with a uniform distribution.

   \return A random double in [0,1].
*/
inline double randomDouble();

/** 
   \brief Returns a random double acording to a normal distribution.

   Returns a random number following a normal distribution with mean 0 and standard deviation 1.

   \return A random double.
*/
double randomNormal();

#endif
