#ifndef POINTH
#define POINTH

/** 
   \file vector.h

   \brief Definition of basic operations between points. 

   Definition of basic operations between points. 
   
   \sa point.c.
*/

/** 
   \brief Computes the squared distance of two points.
   
   Computes the squared distance between two points given as a vector 
   with a given size and considering the topology for each
   dimension.

   The squared distance is only fully computed for points closer than
   a given threshold. This accelerates the distance computations.

   \param t2 The threshold (a square distance!).
   \param s Number of elements in the vectors.
   \param tp The topology for each dimension.
   \param v1 The first point.
   \param v2 The second point.

   \return The squared distance between the points.
*/
double VectorSquaredDistanceTopologyMin(double t2,unsigned int s,unsigned int *tp,
					double *v1,double *v2);

/** 
   \brief Norm of a vector.

   Computes the norm of a vector.

   \param s Size of the vector.
   \param v The vector.

   \return The norm of the vector.
*/
double VectorNorm(unsigned int s,double *v);

/** 
   \brief Normalizes a vector.

   Defines a vector with norm 1.

   \param s Size of the vector.
   \param v The vector.
*/
void VectorNormalize(unsigned int s,double *v);

#endif
