#include "random.h"

#include <sys/types.h>
#include <time.h>
#include <stdlib.h>
#include <math.h>

/** 
   \file random.c

   \brief Implementation of the basic randomization functions. 

   Implementation of the basic randomization functions. 
   
   \sa random.h.
*/

void randomReset()
{
  srand((unsigned int)time(NULL));
  rand();
  rand();
}

void randomSet(unsigned int seed)
{
  srand(seed);
  rand(); /*useful to avoid first rands to be almost equals*/
  rand();

}

double randomDouble()
{
  return((double)rand()/(double)RAND_MAX);
}

double randomNormal()
{
  static int oneCached=0;
  double x1,x2,w;
  double y1;
  static double y2;

  if (oneCached)
    {
      oneCached=0;
      return(y2);
    }
  else
    {
      do {
        x1=2.0*randomDouble()-1.0;
        x2=2.0*randomDouble()-1.0;
        w=x1*x1+x2*x2;
      } while (w>=1.0);
      
      w=sqrt((-2.0*log(w))/w);
      y1=x1*w;
      y2=x2*w;
 
      oneCached=1;
      return(y1);
    }
}
